Module: Google::Apps::Meet
- Defined in:
- lib/google/apps/meet.rb,
lib/google/apps/meet/version.rb
Constant Summary collapse
- VERSION =
"1.3.0"
Class Method Summary collapse
-
.conference_records_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ConferenceRecordsService.
-
.conference_records_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the ConferenceRecordsService service is supported by the current client.
-
.spaces_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for SpacesService.
-
.spaces_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the SpacesService service is supported by the current client.
Class Method Details
.conference_records_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ConferenceRecordsService.
By default, this returns an instance of
Google::Apps::Meet::V2::ConferenceRecordsService::Client
for a gRPC client for version V2 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ConferenceRecordsService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ConferenceRecordsService service. You can determine whether the method will succeed by calling conference_records_service_available?.
About ConferenceRecordsService
REST API for services dealing with conference records.
127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/google/apps/meet.rb', line 127 def self.conference_records_service version: :v2, transport: :grpc, &block require "google/apps/meet/#{version.to_s.downcase}" package_name = Google::Apps::Meet .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Apps::Meet.const_get(package_name).const_get(:ConferenceRecordsService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.conference_records_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the ConferenceRecordsService service is supported by the current client. If true, you can retrieve a client object by calling conference_records_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ConferenceRecordsService service, or if the versioned client gem needs an update to support the ConferenceRecordsService service.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/google/apps/meet.rb', line 151 def self.conference_records_service_available? version: :v2, transport: :grpc require "google/apps/meet/#{version.to_s.downcase}" package_name = Google::Apps::Meet .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Apps::Meet.const_get package_name return false unless service_module.const_defined? :ConferenceRecordsService service_module = service_module.const_get :ConferenceRecordsService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.spaces_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for SpacesService.
By default, this returns an instance of
Google::Apps::Meet::V2::SpacesService::Client
for a gRPC client for version V2 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the SpacesService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the SpacesService service. You can determine whether the method will succeed by calling spaces_service_available?.
About SpacesService
REST API for services dealing with spaces.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/google/apps/meet.rb', line 57 def self.spaces_service version: :v2, transport: :grpc, &block require "google/apps/meet/#{version.to_s.downcase}" package_name = Google::Apps::Meet .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Apps::Meet.const_get(package_name).const_get(:SpacesService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.spaces_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the SpacesService service is supported by the current client. If true, you can retrieve a client object by calling spaces_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SpacesService service, or if the versioned client gem needs an update to support the SpacesService service.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/google/apps/meet.rb', line 81 def self.spaces_service_available? version: :v2, transport: :grpc require "google/apps/meet/#{version.to_s.downcase}" package_name = Google::Apps::Meet .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Apps::Meet.const_get package_name return false unless service_module.const_defined? :SpacesService service_module = service_module.const_get :SpacesService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |